function func = rateqn(x);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DESCRIPTION: Function rateqn contains the equations of the compositional 
% model of cardiac tissue based on mass and volume balance and the constraints
% to solve the model equations. 
%
% This script was used to generate the data published in the following
% article:
% Vinnakota K and Bassingthwaighte JB. Myocardial density and composition:  
% A basis for calculating  intra metabolite concentrations. 
% Am J Physiol Heart Circ Physiol 286: H1742-H1749, 2004.
%
% This script may be freely disributed and used on the
% condition that the aforementioned article be cited.

% VARIABLES & KNOWN PARAMETERS 
% All volumes are expressed in ml/g heart
% All densities are expressend in g/ml
% Tissue constituents: Protein (P), Water (W), Fat (F), small molecular solutes (S)
global Rp Rw Rf Rs fvs
% WHOLE HEART
global Pheart Wheart Fheart Sheart Rheart Vheart

% VASCULAR SPACE: 
% RBC
global Rrbc Vrbc Prbc Wrbc Frbc Srbc
Vrbc = x(1);
% RBC constituent mass fractions
Prbc=x(2); Srbc = x(3); 
% PLASMA:
global Rpl Vpl Ppl Wpl Fpl Spl
Vpl = x(4);
% Plasma constituent mass fractions
 Fpl=x(5); Spl = x(6); 

%INTERSTITIAL FLUID SPACE (ISF)
global Risf Visf Pisf Wisf Fisf Sisf
Risf=x(7);  % ISF density   
Visf=x(8);  % ISF volume
% ISF constituent mass fractions
Pisf=x(9); Wisf=x(10); Fisf = x(11); Sisf = x(12);

% CELL (cell; Myocyte)
global Rcell Vcell 
Rcell=x(13); % Cell density  
Vcell=x(14); % Cell volume

%MITOCHONDRIA (mi)
global Rmi Vmi Pmi Wmi Fmi Smi Vmicell
Vmi = Vcell*Vmicell; % Mitochondrial volume, Page and McCallister, 1973 
% Mitochondrial constituent mass fractions
Pmi = x(15); Wmi = x(16); Fmi = x(17); Smi = x(18); 
%CYTOPLASM (cy; Myofibrils + Sarcoplasm + Other organelles)
global Rcy Vcy Pcy Wcy Fcy Scy Vcycell
% Cytoplasmic constituent mass fractions
Pcy = x(19); Wcy = x(20); Fcy = x(21); Scy = x(22); 
%SARCOPLASMIC RETICULUM (sr)
global Rsr Vsr Psr Wsr Fsr Ssr Vsrcell
Rsr = x(23); % Sarcoplamsic reticulum density
Vsr = Vcell*Vsrcell; % sr volume, Page and McCallister, 1973
% Sarcoplasmic reticulum constituent mass fractions
Psr = x(24); Wsr = x(25); Fsr = x(26); Ssr = x(27);

% Cytoplasmic volume
Vcycell = 1-(Vmicell+Vsrcell);
Vcy = Vcell*Vcycell; % Cytoplasmic volume
 
% Cell constituent mass fractions in g/g tiss
cellP = Rmi*Vmi*Pmi+Rcy*Vcy*Pcy+Rsr*Vsr*Psr; 
cellW = Rmi*Vmi*Wmi+Rcy*Vcy*Wcy+Rsr*Vsr*Wsr; 
cellF = Rmi*Vmi*Fmi+Rcy*Vcy*Fcy+Rsr*Vsr*Fsr; 
cellS = Rcell*Vcell-(cellP+cellW+cellF);
cellTot = cellP+cellW+cellF+cellS;

%cell constituent mass fractions in g/g
global Pcell Wcell Fcell Scell
Pcell = cellP/cellTot; Wcell = cellW/cellTot; Fcell = cellF/cellTot; Scell = cellS/cellTot;


% Variables/Parameters with known data
global Plalb ISFalb Wisfpl Pmitiss Wvolmi Wvolcy Mblood MWpl MWisf


%EQUATIONS AND CONSTRAINTS
     %Mass balance equations (Whole tissue level)
func = [1 - Rrbc*Vrbc - Rpl*Vpl - Risf*Visf - Rcell*Vcell; 
     Pheart - (Rrbc*Vrbc*Prbc + Rpl*Vpl*Ppl + Risf*Visf*Pisf + cellP);
     Wheart - (Rrbc*Vrbc*Wrbc + Rpl*Vpl*Wpl + Risf*Visf*Wisf + cellW);
     Fheart - (Rrbc*Vrbc*Frbc + Rpl*Vpl*Fpl + Risf*Visf*Fisf + cellF);
     Sheart - (Rrbc*Vrbc*Srbc + Rpl*Vpl*Spl + Risf*Visf*Sisf + cellS);
     Ppl+Wpl+Fpl+Spl-1;
     Pisf+Wisf+Fisf+Sisf-1;
     Prbc+Wrbc+Frbc+Srbc-1;
     abs(Ppl)+abs(Wpl)+abs(Fpl)+abs(Spl)-1;
     abs(Pisf)+abs(Wisf)+abs(Fisf)+abs(Sisf)-1;
     abs(Prbc)+abs(Wrbc)+abs(Frbc)+abs(Srbc)-1;
     
     %Volume balance equations (Whole tissue level)
     Vheart - (Vrbc+Vpl+Visf+Vcell);
     1/Rrbc - (Prbc/Rp+Wrbc/Rw+Frbc/Rf+fvs*Srbc/Rs);
     1/Rpl - (Ppl/Rp+Wpl/Rw+Fpl/Rf+fvs*Spl/Rs);
     1/Risf - (Pisf/Rp+Wisf/Rw+Fisf/Rf+fvs*Sisf/Rs);
          
     %Mass balance equations (cell level)
     (Rcell - Rmi*Vmicell - Rcy*Vcycell - Rsr*Vsrcell);
     Pmi+Wmi+Fmi+Smi-1;
     Psr+Wsr+Fsr+Ssr-1;
     Pcy+Wcy+Fcy+Scy-1;
     abs(Pmi)+abs(Wmi)+abs(Fmi)+abs(Smi)-1;
     abs(Psr)+abs(Wsr)+abs(Fsr)+abs(Ssr)-1;
     abs(Pcy)+abs(Wcy)+abs(Fcy)+abs(Scy)-1;
     
     %Volume balance equations (cell level)
     (1/Rmi - (Pmi/Rp+Wmi/Rw+Fmi/Rf+fvs*Smi/Rs));
     (1/Rcy - (Pcy/Rp+Wcy/Rw+Fcy/Rf+fvs*Scy/Rs));
     (1/Rsr - (Psr/Rp+Wsr/Rw+Fsr/Rf+fvs*Ssr/Rs));
     
     %Constraints
     %RBC
     Rrbc*Vrbc+Rpl*Vpl - Mblood;
     %Plasma
     Rpl*Vpl*Wpl - MWpl;
     %isf parameters
     Risf*Visf*Wisf - MWisf;
     Fpl/(Plalb/Rpl) - Fisf/(ISFalb/Risf);
     %Sub-cellular parameters
     (Rmi*Vmi*Pmi - Pmitiss); % Idell-Wenger et al, 1978 
     Wmi*Rmi/Rw - Wvolmi; % von Zglinicki and Bimmler, 1987
     Wcy*Rcy/Rw - Wvolcy; 
     Psr*Rsr*0.035/0.607 - 0.0292; % Bers, 2001
     %Constraint set to keep the solutions positive 
     (((x<0).*(10.*x))').^2];    
 
 % SUMMARY
 % NUMBER OF VARIABLES = 27
 % EQUATION TYPE  | Number
 % LINEAR | 7
 % NONLINEAR | 12
 % CONSTRAINT TYPE | NUMBER
 % LINEAR | 
 % NONLINEAR | 14 + 27
 
 %REFERENCES: