%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DESCRIPTION: This matlab m file solves tissue and organ composition equations of rat heart myocardium
% specified in function rateqn.m, through a montecarlo simulation. The first part of the program
% consists of declaration of the variables as global variables to enable sharing with ratequation.m
% This is followed by initialization of the means and standard devations of the known variables with values
% from the literature. Then the initial guess for the function 'fsolve' is initialized. The next part is
% the Monte-Carlo scheme which draws the values of the known variables from their distributions and calls
% 'fsolve' to solve the equations specified in the file rateqn.m. The solutions are collected in matrices.
% Then the mass and the composition of the large vessels are computed. The key information for this is the
% large vessel hematocrit and the fraction of total vascular volume constituted by the large vessels.
% Using large vessel data, the heart composition variables are renormalized to myocardium values (Table 3) where
% myocardium is defined as the heart minus the large vessels.
%
% This script was used to generate the data published in the following
% article:
% Vinnakota K and Bassingthwaighte JB. Myocardial density and composition:  
% A basis for calculating  intra metabolite concentrations. 
% Am J Physiol Heart Circ Physiol 286: H1742-H1749, 2004.
%
% This script may be freely disributed and used on the
% condition that the aforementioned article be cited.



% Monte Carlo Simulation to estimate Tissue and organ composition with their variances

global Rp Rw Rf Rs fvs
% Mean protein density 
Rp = 1.34; % Brozek et al, 1963; 
% Water density at 23 C
Rw=0.9976; 
%Mean tissue fat density
smRf=0.901; ssdRf = 0.0067; %Allen et al, 1953
sdRf = sqrt(-log(1-ssdRf^2/smRf^2)); mRf = log(smRf)-sdRf^2/2;
% Mean apparent density of small molecular solutes
Rs=3.317; % Brozek et al, 1963
% Mean fractional volume occupied by small molecular solutes
fvs = 1; 

% WHOLE HEART
% Whole heart constituent mass fractions
global Pheart Wheart Fheart Sheart Rheart Vheart
 
smWheart = 0.79; %Rat, Dobson and Cieslar, 1997 
ssdWheart = 0.01; %Rat, Dobson and Cieslar, 1997
sdWheart = sqrt(-log(1-ssdWheart^2/smWheart^2)); mWheart = log(smWheart)-sdWheart^2/2;

smFheart = 0.0205; % Guinea Pig, Dible, 1932
ssdFheart = 0.01*smFheart; %Assumed similar to the fractional standard deviaton in water measurement
sdFheart = sqrt(-log(1-ssdFheart^2/smFheart^2)); mFheart = log(smFheart)-sdFheart^2/2;

smPheart = 0.1758; %Calculated from a P/S ratio of 12.907 = (1/1.4-1/3.317)/(1/1.34-1/1.4) obtained from the combined density of 
                   %P and S of 1.4 in rat, guinea pig and rabbit (Allen, et al) 
ssdPheart = 0.01*smPheart; %Assumed similar to the variance in water measurement
sdPheart = sqrt(-log(1-ssdPheart^2/smPheart^2)); mPheart = log(smPheart)-sdPheart^2/2;

smSheart = 1-smWheart-smFheart-smPheart;
ssdSheart = 0.015*smSheart; %Variance in plasma osmolarity, Giegy scientific tables vol.3 Composition of blood.
                            %Assume the solute which is mostly soft tissue mineral to have the same variance   
sdSheart = sqrt(-log(1-ssdSheart^2/smSheart^2)); mSheart = log(smSheart)-sdSheart^2/2;
                  
                  
% VASCULAR SPACE: 
% RBC
global Rrbc Vrbc Prbc Wrbc Frbc Srbc
Rrbc_obs = log([1.0989 1.098 1.0944]);      % Observations 1,2 in man (Altman & Dittmer), 3 in dog (Effros and Chinard, 1979)
smRrbc = mean(exp(Rrbc_obs)); ssdRrbc = std(exp(Rrbc_obs));
mRrbc=mean(Rrbc_obs);sdRrbc=std(Rrbc_obs);  % RBC density, g/ml

smWrbc = 0.67; ssdWrbc = 0.015; %RBC water fraction, Effros and Chinard
sdWrbc = sqrt(-log(1-ssdWrbc^2/smWrbc^2)); mWrbc = log(smWrbc)-sdWrbc^2/2; %Dog erythrocyte data, Effros and Chinard
 
smFrbc_obs = 510; ssdFrbc_obs = 51; sdFrbc_obs = sqrt(-log(1-ssdFrbc_obs^2/smFrbc_obs^2)); mFrbc_obs = log(smFrbc_obs)-sdFrbc_obs^2/2; 
Frbc_obs = exp(sdFrbc_obs*randn+mFrbc_obs); % Fat content of RBC expressed in mg/100 ml, Farquhar (1962) as quoted by Pennell, 1974
 
fsd = 0.01;
% PLASMA:
global Rpl Vpl Ppl Wpl Fpl Spl
Rpl_obs=log([1.0262 1.023 1.022]);%Plasma density, Rattus sp, Altman and Dittmer (Circulation).
mRpl = mean(Rpl_obs); sdRpl = std(Rpl_obs);

%Plasma water in g/l plasma, Altman and Dittmer
Wpl_obs = log([946]); %Rat
                
%Plasma protein in g/l plasma, Altman and Dittmer
Ppl_obs = log([60]); %Rat
                    
%INTERSTITIAL FLUID SPACE (ISF)
global Risf Visf Pisf Wisf Fisf Sisf

% CELL (cell; Myocyte)
global Rcell Vcell Pcell Wcell Fcell Scell

%MITOCHONDRIA (mi)
global Rmi Vmi Pmi Wmi Fmi Smi Vmicell
mRmi=1.1; % Mitochondrial density, von Zglinicki and Bimmler, 1987
smVmicell = 0.32; ssdVmicell = 0.0183*sqrt(3);
sdVmicell = sqrt(-log(1-ssdVmicell^2/smVmicell^2)); mVmicell = log(smVmicell)-sdVmicell^2/2;

%CYTOPLASM (cy; Myofibrils + Sarcoplasm + Other organelles)
% Cytoplasmic density
global Rcy Vcy Pcy Wcy Fcy Scy Vcycell
mRcy=1.055; % von Zglinicki and Bimmler, 1987

%SARCOPLASMIC RETICULUM (sr)
global Rsr Vsr Psr Wsr Fsr Ssr Vsrcell
smVsrcell = 0.035; ssdVsrcell = 0.0002; %Page and McCallister, 1973
sdVsrcell = sqrt(-log(1-ssdVsrcell^2/smVsrcell^2)); mVsrcell = log(smVsrcell)-sdVsrcell^2/2;

% Variables with known data
global Plalb ISFalb Wisfpl Pmitiss ratioPmiPtiss Wvolmi Wvolcy Mblood MWpl MWisf

smPlalb = 0.035; ssdPlalb = 0.001; % g/ml plasma, Plasma albumin, Wiig et al., 2000.
sdPlalb = sqrt(-log(1-ssdPlalb^2/smPlalb^2)); mPlalb = log(smPlalb)-sdPlalb^2/2;

smISFalb = 0.017; ssdISFalb = 0.001; % g/ml ISF, ISF albumin, Wiig et al., 2000.
sdISFalb = sqrt(-log(1-ssdISFalb^2/smISFalb^2)); mISFalb = log(smISFalb)-sdISFalb^2/2;

smPmitiss = 0.053; ssdPmitiss = 0.001; %Mitochondria protein per gram tissue, Idell-Wenger et al., 1978
sdPmitiss = sqrt(-log(1-ssdPmitiss^2/smPmitiss^2)); mPmitiss = log(smPmitiss)-sdPmitiss^2/2;

Wvolmi = 0.725; %Water volume fraction of cytosol, von Zglinicki et al., 1987
Wvolcy = 0.845; %Water volume fraction of mitochndria, von Zglinicki et al., 1987

smMblood = 0.106; %Mass of blood in heart, g/g wet, Dobson and Cieslar, 1997
ssdMblood = 0.011; %g/g wet 
sdMblood = sqrt(-log(1-ssdMblood^2/smMblood^2)); mMblood = log(smMblood)-sdMblood^2/2;

smMWpl = 0.059; %g/g wet, Mass of plasma water, Dobson and Cieslar, 1997
ssdMWpl = 0.007; %g/g wet
sdMWpl = sqrt(-log(1-ssdMWpl^2/smMWpl^2)); mMWpl = log(smMWpl)-sdMWpl^2/2;

smMWisf = 0.153; %g/g wet, Mass of ISF water, Dobson and Ciesar, 1997
ssdMWisf = 0.011; %g/g wet
sdMWisf = sqrt(-log(1-ssdMWisf^2/smMWisf^2)); mMWisf = log(smMWisf)-sdMWisf^2/2;


%Initial guess
iVrbc = 0.0301; 
% RBC constituent mass fractions
iPrbc = 0.3045; iSrbc = 0.0198; 
% PLASMA:
iVpl = 0.0574;
% Plasma constituent mass fractions
 iFpl=0.0029; iSpl = 0.0126; 
%INTERSTITIAL FLUID SPACE (ISF)
iRisf=1.023;  % ISF density   
iVisf=0.1646;  % ISF volume
% ISF constituent mass fractions
iPisf=0.06; iWisf=0.9233; iFisf = 0.0013; iSisf = 0.0129;
% CELL (cell; Myocyte)
iRcell=1.0647; % Cell density  
iVcell=0.6966; % Cell volume
%MITOCHONDRIA (mi)
% Mitochondrial constituent mass fractions
iPmi = 0.6607; iWmi = 0.2791; iFmi = 0.0306; iSmi = 0.0296; 
%CYTOPLASM (cy; Myofibrils + Sarcoplasm + Other organelles)
% Cytoplasmic constituent mass fractions
iPcy = 0.1545; iWcy = 0.8049; iFcy = 0.0253; iScy = 0.0153; 
%SARCOPLASMIC RETICULUM (sr)
iRsr = 1.1366; % Sarcoplamsic reticulum density
% Sarcoplasmic reticulum constituent mass fractions
iPsr = 0.445; iWsr = 0.5147; iFsr = 0.0244; iSsr = 0.0159;

guess = [iVrbc iPrbc iSrbc iVpl iFpl iSpl iRisf iVisf iPisf iWisf iFisf iSisf iRcell iVcell iPmi iWmi iFmi iSmi iPcy iWcy iFcy iScy iRsr iPsr iWsr iFsr iSsr];




%Montecarlo simulation
%Set counters to zero
i = 0; %Monte-Carlo iteration
accept = 0;%Accepted solution
discard = 0; %Discarded iteration

%Initialize storage matrices
SOLUTIONS=[]; DISCARD=[]; unfiltered = []; filtered = [];
heart=[];plasma=[];RBC=[];ISF=[];cell=[];cyto=[];mito=[];sr=[];

%fsolve settings
%Set the options to default values for fsolve
opts = optimset('fsolve');
%Reduce the tolerances to 1e-8 from a default value of 1e-6
opts = optimset('Typicalx',guess, 'TolFun',1e-8,'TolX',1e-8,'DerivativeCheck', 'off', ...
           'Diagnostics', 'off','DiffMaxChange', 0.1000, 'DiffMinChange',1.0000e-08,'Display','final', ...
           'Jacobian', 'off','JacobPattern','sparse(ones(jrows,jcols))','LargeScale','on', ...
        'LevenbergMarquardt', 'off', 'LineSearchType','quadcubic','MaxFunEvals', 3000, ...
          'MaxIter', 400, 'MaxPCGIter', 'max(1,floor(numberofvariables/2))','TolPCG', 0.1000);


while(i<30000)
    %Generate random values from the distributions of the known quantities
    %Constituent densities
    Rf = exp(sdRf*randn+mRf); %Fat
    %Heart constituent mass fractions
    Pheart = exp(sdPheart*randn+mPheart); Sheart = exp(sdSheart*randn+mSheart); Fheart = exp(sdFheart*randn+mFheart); 
    if ((1-(Pheart+Fheart+Sheart) > mWheart-2.5*ssdWheart) | (1+(Pheart+Fheart+Sheart) < smWheart+2.5*ssdWheart) )
        Wheart =  1-(Pheart+Fheart+Sheart);
    end
    % Whole heart parameters
    Rheart = 1/(Pheart/Rp+Wheart/Rw+Fheart/Rf+fvs*Sheart/Rs); %Heart density
    Vheart = 1/Rheart; %Specific volume
    %Vascular region          
    Mblood = exp(sdMblood*randn + mMblood); %Mass of blood g/g heart
    %Plasma
    MWpl = exp(sdMWpl*randn + mMWpl); %Mass of Water in plasma g/g heart
    Rpl = exp(sdRpl*randn+mRpl); %Plasma density
    Wpl = exp(std(Wpl_obs)*randn+mean(Wpl_obs))/(1000*Rpl); %Plasma water mass fraction
    Ppl = exp(std(Ppl_obs)*randn+mean(Ppl_obs))/(1000*Rpl); %Plasma protein mass fraction
    Plalb = exp(sdPlalb*randn+mPlalb);  %Plasma albumin
    %RBC 
    Rrbc = exp(sdRrbc*randn + mRrbc);crRrbc = (Rrbc<smRrbc-2.5*ssdRrbc)|(Rrbc>smRrbc+2.5*ssdRrbc);
    Wrbc = exp(sdWrbc*randn+mWrbc);crWrbc = (Wrbc<smWrbc-2.5*ssdWrbc)|(Wrbc>smWrbc+2.5*ssdWrbc);
    Frbc = Frbc_obs*1e-3/(100*Rrbc);
    %ISF
    MWisf = exp(sdMWisf*randn + mMWisf); %Mass of water in ISF
    ISFalb = exp(sdISFalb*randn+mISFalb); %ISF albumin
    %Cytosol
    Rcy = (fsd*randn+1)*mRcy; %Density
    %Mitochondria
    Rmi = (fsd*randn+1)*mRmi; %Density
    Vmicell = exp(sdVmicell*randn+mVmicell); %Volume density in cell
    Pmitiss = exp(sdPmitiss*randn + mPmitiss); 
    %Sarcoplasmic Reticulum
    Vsrcell = exp(sdVsrcell*randn+mVsrcell); %Volume density in cell
    
    unfiltered = [unfiltered; [Rf Pheart Sheart Fheart Wheart Rheart Mblood MWpl Rpl Wpl Ppl Plalb Rrbc Wrbc Frbc MWisf ISFalb Rcy Rmi Vmicell Pmitiss Pmitiss Vsrcell]];
     
    %Verify for physical implausibility
    [x fval exitflag output,JACOB] = fsolve(@rateqn,guess,opts);
    if (gt(sum(lt(x,0)),0)|(exitflag<1)|(Spl<=0)|(Srbc<=0)|(Sisf<=0)|(Scy<=0)|(Smi<=0)|(Ssr<=0))
            discard = discard +1;
        else
            SOLUTIONS = [SOLUTIONS; x];
            heart = [heart;[Rheart Vheart Wheart Pheart Fheart Sheart]];
            plasma = [plasma;[Rpl Vpl Wpl Ppl Fpl Spl]];
            RBC = [RBC;[Rrbc Vrbc Wrbc Prbc Frbc Srbc]];
            ISF = [ISF;[Risf Visf Wisf Pisf Fisf Sisf]];
            cell = [cell;[Rcell Vcell Wcell Pcell Fcell Scell]];
            cyto = [cyto;[Rcy Vcy Wcy Pcy Fcy Scy]];
            mito = [mito;[Rmi Vmi Wmi Pmi Fmi Smi]];
            sr = [sr;[Rsr Vsr Wsr Psr Fsr Ssr]];            
            accept=accept+1;
            filtered = [filtered; [Rf Pheart Sheart Fheart Wheart Rheart Mblood MWpl Rpl Wpl Ppl Plalb Rrbc Wrbc Frbc MWisf ISFalb Rcy Rmi Vmicell Pmitiss Pmitiss Vsrcell]];
            
        end
        i = i+1;
end

accept
discard

%Large vessels
%Fraction of large vessels in the total vascular volume
LV_fract = 1.2/8.6; %Judd and Levy, 1991
%Hematocrit
Hct_LV = 0.45; %Dobson and cieslar, the Hct value ranged from 35-45%
%Large Vessels
%Density
R_LV = Hct_LV.*RBC(:,1)+(1-Hct_LV).*plasma(:,1);
%Volume in ml/g organ
V_LV = LV_fract.*(RBC(:,2)+plasma(:,2));
%Mass in g/g organ
M_LV = R_LV.*V_LV;
%Water fraction
W_LV = (Hct_LV.*RBC(:,1).*RBC(:,3)+(1-Hct_LV).*plasma(:,1).*plasma(:,3))./R_LV;
%Protein fraction
P_LV = (Hct_LV.*RBC(:,1).*RBC(:,4)+(1-Hct_LV).*plasma(:,1).*plasma(:,4))./R_LV;
%Fat fraction
F_LV = (Hct_LV.*RBC(:,1).*RBC(:,5)+(1-Hct_LV).*plasma(:,1).*plasma(:,5))./R_LV;
%Solute fraction
S_LV = (Hct_LV.*RBC(:,1).*RBC(:,6)+(1-Hct_LV).*plasma(:,1).*plasma(:,6))./R_LV;
%Large vessel data array
LV = [R_LV V_LV W_LV P_LV F_LV S_LV];
%Mass of myocardium per gram organ
M_myocard = 1-M_LV;
%Myocardium parameters; volume in g/g tissue
myocard = (-[R_LV.*V_LV.*W_LV R_LV.*V_LV.*P_LV R_LV.*V_LV.*F_LV R_LV.*V_LV.*S_LV] + [heart(:,3) heart(:,4) heart(:,5) heart(:,6)])./[M_myocard M_myocard M_myocard M_myocard];
myocard = [M_myocard./(-V_LV+heart(:,2)) (-V_LV+heart(:,2))./(M_myocard) myocard];

%Calculating Volumes of Tissue (Myocardium) regions per gram of tissue
%organ mass/ g tissue
gorgpergtiss = 1./(1-M_LV);
%RBC volume in Tissue; ml/g tiss
RBC(:,2) = (RBC(:,2) - Hct_LV.*(V_LV)).*gorgpergtiss;
%Plasma volume in tissue; ml/g tiss
plasma(:,2) = (plasma(:,2) - (1-Hct_LV).*(V_LV)).*gorgpergtiss;
%ISf volume in tissue; ml/g tiss
ISF(:,2) = ISF(:,2).*gorgpergtiss;
%Cell volume in tissue; ml/g tiss
cell(:,2) = cell(:,2).*gorgpergtiss;
%Cyto volume in tissue; ml/g tiss
cyto(:,2) = cyto(:,2).*gorgpergtiss;
%mito volume in tissue; ml/g tiss
mito(:,2) = mito(:,2).*gorgpergtiss;
%sr volume in tissue; ml/g tiss
sr(:,2) = sr(:,2).*gorgpergtiss;

%Table 3
display('TABLE 3')
MEANX = mean(SOLUTIONS,1);
STDX = std(SOLUTIONS,1);
heart_MEAN = mean(heart,1)
heart_SD = std(heart,1);
heart_CV = 100.*heart_SD./heart_MEAN
myocard_MEAN = mean(myocard,1)
myocard_CV = 100.*std(myocard,1)./mean(myocard,1)
Plasma_MEAN = mean(plasma,1)
Plasma_SD = std(plasma,1);
Plasma_CV = 100.*Plasma_SD./Plasma_MEAN
RBC_MEAN = mean(RBC,1)
RBC_SD = std(RBC,1);
RBC_CV = 100.*RBC_SD./RBC_MEAN
ISF_MEAN = mean(ISF,1)
ISF_SD = std(ISF,1);
ISF_CV = 100.*ISF_SD./ISF_MEAN
cell_MEAN = mean(cell,1)
cell_SD = std(cell,1);
cell_CV = 100.*cell_SD./cell_MEAN
cyto_MEAN = mean(cyto,1)
cyto_SD = std(cyto,1);
cyto_CV = 100.*cyto_SD./cyto_MEAN
mito_MEAN = mean(mito,1)
mito_SD = std(mito,1);
mito_CV = 100.*mito_SD./mito_MEAN
sr_MEAN = mean(sr,1)
sr_SD = std(sr,1);
sr_CV = 100.*sr_SD./sr_MEAN


%Table 4
%Microvasculature (= small blood vessels + capillaries)
RBCheart = RBC(:,2)./gorgpergtiss + Hct_LV.*V_LV;
plasmaheart = plasma(:,2)./gorgpergtiss + (1-Hct_LV).*V_LV;
V_micro = (1-LV_fract).*(RBC(:,2)+plasma(:,2));
M_micro = RBC(:,1).*RBCheart+plasma(:,1).*plasmaheart - M_LV;
R_micro = M_micro./V_micro;
W_micro = (RBC(:,1).*RBCheart.*RBC(:,3)+plasma(:,1).*plasmaheart.*plasma(:,3) - M_LV.*W_LV)./M_micro;
P_micro = (RBC(:,1).*RBCheart.*RBC(:,4)+plasma(:,1).*plasmaheart.*plasma(:,4) - M_LV.*P_LV)./M_micro;
F_micro = (RBC(:,1).*RBCheart.*RBC(:,5)+plasma(:,1).*plasmaheart.*plasma(:,5) - M_LV.*F_LV)./M_micro;
S_micro = (RBC(:,1).*RBCheart.*RBC(:,6)+plasma(:,1).*plasmaheart.*plasma(:,6) - M_LV.*S_LV)./M_micro;
display('TABLE 4')
%Large vessels
large_vessels = mean([[R_LV.*V_LV.*W_LV R_LV.*V_LV.*P_LV R_LV.*V_LV.*F_LV R_LV.*V_LV.*S_LV] sum([R_LV.*V_LV.*W_LV R_LV.*V_LV.*P_LV R_LV.*V_LV.*F_LV R_LV.*V_LV.*S_LV],2)])
%Microvasculature
microvasculature = mean([[R_micro.*V_micro.*W_micro R_micro.*V_micro.*P_micro R_micro.*V_micro.*F_micro R_micro.*V_micro.*S_micro] sum([R_micro.*V_micro.*W_micro R_micro.*V_micro.*P_micro R_micro.*V_micro.*F_micro R_micro.*V_micro.*S_micro],2)])
%ISF
ISFheart = [ISF(:,1).*ISF(:,2).*ISF(:,3)./gorgpergtiss ISF(:,1).*ISF(:,2).*ISF(:,4)./gorgpergtiss ISF(:,1).*ISF(:,2).*ISF(:,5)./gorgpergtiss ISF(:,1).*ISF(:,2).*ISF(:,6)./gorgpergtiss];
interstitium = mean([ISFheart sum(ISFheart,2)])
%cell
cellheart = [cell(:,1).*cell(:,2).*cell(:,3)./gorgpergtiss cell(:,1).*cell(:,2).*cell(:,4)./gorgpergtiss cell(:,1).*cell(:,2).*cell(:,5)./gorgpergtiss cell(:,1).*cell(:,2).*cell(:,6)./gorgpergtiss];
totalcell=mean([cellheart sum(cellheart,2)])
%cytoplasm
cytoheart = [cyto(:,1).*cyto(:,2).*cyto(:,3)./gorgpergtiss cyto(:,1).*cyto(:,2).*cyto(:,4)./gorgpergtiss cyto(:,1).*cyto(:,2).*cyto(:,5)./gorgpergtiss cyto(:,1).*cyto(:,2).*cyto(:,6)./gorgpergtiss];
cytoplasm=mean([cytoheart sum(cytoheart,2)])
%mitochondria
mitoheart = [mito(:,1).*mito(:,2).*mito(:,3)./gorgpergtiss mito(:,1).*mito(:,2).*mito(:,4)./gorgpergtiss mito(:,1).*mito(:,2).*mito(:,5)./gorgpergtiss mito(:,1).*mito(:,2).*mito(:,6)./gorgpergtiss];
mitochondria=mean([mitoheart sum(mitoheart,2)])
%sarcoplasmic reticulum
srheart = [sr(:,1).*sr(:,2).*sr(:,3)./gorgpergtiss sr(:,1).*sr(:,2).*sr(:,4)./gorgpergtiss sr(:,1).*sr(:,2).*sr(:,5)./gorgpergtiss sr(:,1).*sr(:,2).*sr(:,6)./gorgpergtiss];
%Total organ: heart
sarcoplasmicreticulum=mean([srheart sum(srheart,2)])
sum([large_vessels;microvasculature;interstitium;totalcell],1)
[heart_MEAN(1)*heart_MEAN(2).*heart_MEAN(3:6) sum(heart_MEAN(1)*heart_MEAN(2).*heart_MEAN(3:6),2)]

%Table 5
DATA = [heart myocard plasma RBC ISF cell cyto mito sr];

%Water spaces
d=6;
for i = 1:9
    Water(i,:) = [mean(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)) ...
            std(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)) ...
            100*std(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d))/mean(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d))]./Rw;
end
Water

for i = 1:9
    Water_dry(i,:) = [mean(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./(1-DATA(:,3))) ...
            std(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./(1-DATA(:,3))) ...
            100*std(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./(1-DATA(:,3)))/mean(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./(1-DATA(:,3)))]./Rw;
end
Water_dry

for i = 1:9
    Water_protein(i,:) = [mean(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./DATA(:,4)) ...
            std(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./DATA(:,4)) ...
            100*std(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./DATA(:,4))/mean(DATA(:,1+(i-1)*d).*DATA(:,2+(i-1)*d).*DATA(:,3+(i-1)*d)./DATA(:,4))]./Rw;
end
Water_protein

%Plotting histograms of tissue composition variables

figure;nvar=8;npar=6;
for j = 1:1:nvar
    for i = 1:1:npar
        x = 0.1+(i-1)*0.9/npar;
        y = 0.1+(j-1)*0.9/nvar;
        axes('position',[x,y,0.9/npar,0.9/nvar]);
        column = (npar*nvar+1 - (j-1)*npar) + (i-1); 
        Z = (DATA(:,column)-mean(DATA(:,column)))./std(DATA(:,column));
        [N,X] = hist(Z,20);
        if ((i==1)&(j~=1))
            bar(X,N./(sum(N)*(X(length(X))-X(1))/(length(X)-1)),'hist')
            h = findobj(gca,'Type','patch');
            set(h,'FaceColor','k');
            set(gca,'XLim',[-3*std(Z) 3*std(Z)],'XTick',std(Z).*[-2 -1 0 1 2] ,'TickDir','out','TickLength',[0.02 0],'FontSize',10,'FontWeight','normal','XTickLabel',{'';'';'';'';''},...
            'YLim', [0 0.8], 'YTick',[0.0 0.2 0.4 0.6], 'YTickLabel',{'0','','0.4',''})
    elseif ((i==1)&(j==1))
        bar(X,N./(sum(N)*(X(length(X))-X(1))/(length(X)-1)),'hist')
        h = findobj(gca,'Type','patch');
        set(h,'FaceColor','k');
        set(gca,'XLim',[-3*std(Z) 3*std(Z)],'XTick',std(Z).*[-2 -1 0 1 2] ,'TickDir','out','TickLength',[0.02 0],'FontSize',10,'FontWeight','normal','XTickLabel',{'-2';'-1';'0';'1';'2'},...
            'YLim', [0 0.8], 'YTick',[0.0 0.2 0.4 0.6], 'YTickLabel',{'0','','0.4',''})
    elseif ((i~=1)&(j==1))
        bar(X,N./(sum(N)*(X(length(X))-X(1))/(length(X)-1)),'hist')
        h = findobj(gca,'Type','patch');
        set(h,'FaceColor','k');
            set(gca,'XLim',[-3*std(Z) 3*std(Z)],'XTick',std(Z).*[-2 -1 0 1 2] ,'TickDir','out','TickLength',[0.02 0],'FontSize',10,'FontWeight','normal','XTickLabel',{'-2';'-1';'0';'1';'2'},...
            'YLim', [0 0.8], 'YTick',[0.2 0.4 0.6], 'YTickLabel',{'','',''})
    else
        bar(X,N./(sum(N)*(X(length(X))-X(1))/(length(X)-1)),'hist')
        h = findobj(gca,'Type','patch');
        set(h,'FaceColor','k');
            set(gca,'XLim',[-3*std(Z) 3*std(Z)],'XTick',std(Z).*[-2 -1 0 1 2] ,'TickDir','out','TickLength',[0.02 0],'FontSize',10,'FontWeight','normal','XTickLabel',{'';'';'';'';''},...
            'YLim', [0 0.8], 'YTick',[0.2 0.4 0.6], 'YTickLabel',{'','',''})
    end
end
end


%Representation of tissue in a simplified three component system (P+S, F, W)
%Define the vertices of the triangular patch object
a=1;h=a*sqrt(3)/2;
vert = [0 0 0; 1 0 0; a/2 a*sqrt(3)/2 0];
theta = pi/3;
%Defining face matrix
fac = [1 2 3];
%Defining face color
tcolor = [1 1 1];
%Plotting on square axes
figure; axis square; axis off;
patch('Faces',fac,'Vertices',vert,'FaceVertexCData',tcolor,'FaceColor','flat','FaceAlpha',1);
hold

for i= 0:10
    x1(i+1) = (a*i/10)*cos(theta); y1(i+1) = (a*i/10)*sin(theta);
    x2(i+1) = a*i/10; y2(i+1) = 0;
    x3(i+1) = a + (a*i/10)*cos(pi-theta); y3(i+1) = (a*i/10)*sin(theta);
end

for i=1:11
    if(i==11)
        plot([x1(i) x2(i)],[y1(i) y2(i)],'k','LineWidth',2);
    else
        plot([x1(i) x2(i)],[y1(i) y2(i)],'k','LineWidth',1.25);
    end
    if(i==1)
        plot([x2(i) x3(12-i)],[y2(i) y3(12-i)],'k','LineWidth',2);
    else
        plot([x2(i) x3(12-i)],[y2(i) y3(12-i)],'k','LineWidth',1.25);
    end
    if(i==1)
        plot([x3(i) x1(i)],[y3(i) y1(i)],'k','LineWidth',2);
    else
        plot([x3(i) x1(i)],[y3(i) y1(i)],'k','LineWidth',1.25);
    end
end
l1=x1;l2=x2;l3=x3;m1=y1;m2=y2;m3=y3;
text(0,0,['(W=0, P+S=1, F=0)'], 'HorizontalAlignment','Center','VerticalAlignment','Top','FontSize',18)
text(a,0,['(W=0, P+S=0, F=1)'], 'HorizontalAlignment','Center','VerticalAlignment','Top','FontSize',18)
text(a/2,h,['(W=1, P+S= 0, F=0)'], 'HorizontalAlignment','Center','VerticalAlignment','Bottom','FontSize',18)

Str(1) = {'W = Water'}; Str(2) = {'P+S = Protein + Solutes'}; Str(3) = {'F = Fat'};
text(0.1, 0.8*h, Str,'FontSize',18);


xytiss = inv([0 1;-tan(theta) 1])*[heart_MEAN(3)*h; -heart_MEAN(5)*h*sec(theta)];
plot(xytiss(1),xytiss(2),'ks','MarkerSize',6, 'MarkerEdgeColor','k','MarkerFaceColor','k')
text(xytiss(1)+0.01,xytiss(2),['(P+S = ',num2str(heart_MEAN(4)+heart_MEAN(6)),', F = ',num2str(heart_MEAN(5)),', W = ',num2str(heart_MEAN(3)),')'],...
   'HorizontalAlignment','Left','VerticalAlignment','Middle','FontSize',18)


%Figure 1 Tissue representation in three component space
figure; axis square; axis off;
patch('Faces',fac,'Vertices',vert,'FaceVertexCData',[1 1 1],'FaceColor','flat','FaceAlpha',1);
hold
psratio = heart_MEAN(6)/heart_MEAN(4);
P = (1/heart_MEAN(1)-1/Rw)/(1/Rp+fvs*psratio/Rs-(1+psratio)/Rw);
l = h*(1-P*(1+psratio))*sec(theta/2);
x1 = l*cos(theta); y1=l*sin(theta);
P = (1/heart_MEAN(1)-1/smRf)/(1/Rp+fvs*psratio/Rs-(1+psratio)/smRf);
x2 = h*(1-P*(1+psratio))*sec(theta/2); y2 = 0;
isodensx = [x1 x2]; isodensy = [y1 y2]; 
xytiss = inv([0 1;-tan(theta) 1])*[heart_MEAN(3)*h; -heart_MEAN(5)*h*sec(theta)];
PSdehyd = 1/(1+heart_MEAN(5)/(heart_MEAN(4)+heart_MEAN(6)));
dehydx = [xytiss(1) h*(1-PSdehyd)*sec(theta/2)]; dehydy = [xytiss(2) 0];
plot(dehydx(1),dehydy(1),'ko','MarkerSize',8);
plot(isodensx,isodensy,'-','Color',[0 0 0],'LineWidth',2);
plot([xytiss(1) a/2],[xytiss(2) h],'k--','LineWidth',2)
plot(dehydx,dehydy,'k:','LineWidth',2);
legend ('Myocardium','Constant density line','Edema line','Dehydration line');

x1=l1;x2=l2;x3=l3;y1=m1;y2=m2;y3=m3;
for i=1:11
    if(i==11)
        plot([x1(i) x2(i)],[y1(i) y2(i)],'k','LineWidth',1.5);
    else
        plot([x1(i) x2(i)],[y1(i) y2(i)],'k','LineWidth',0.75);
    end
    if(i==1)
        plot([x2(i) x3(12-i)],[y2(i) y3(12-i)],'k','LineWidth',1.5);
    else
        plot([x2(i) x3(12-i)],[y2(i) y3(12-i)],'k','LineWidth',0.75);
    end
    if(i==1)
        plot([x3(i) x1(i)],[y3(i) y1(i)],'k','LineWidth',1.5);
    else
        plot([x3(i) x1(i)],[y3(i) y1(i)],'k','LineWidth',0.75);
    end
end

%Figure 2: Representation of regions in three phase space
figure; axis square; axis off;
tcolor = [1 1 1];
patch('Faces',fac,'Vertices',vert,'FaceVertexCData',tcolor,'FaceColor','flat','FaceAlpha',1);
hold
xyrbc = inv([0 1;-tan(theta) 1])*[RBC_MEAN(3)*h; -RBC_MEAN(5)*h*sec(theta)];
xypl = inv([0 1;-tan(theta) 1])*[Plasma_MEAN(3)*h; -Plasma_MEAN(5)*h*sec(theta)];
xyisf = inv([0 1;-tan(theta) 1])*[ISF_MEAN(3)*h; -ISF_MEAN(5)*h*sec(theta)];
xycy = inv([0 1;-tan(theta) 1])*[cyto_MEAN(3)*h; -cyto_MEAN(5)*h*sec(theta)];
xymi = inv([0 1;-tan(theta) 1])*[mito_MEAN(3)*h; -mito_MEAN(5)*h*sec(theta)];
xysr = inv([0 1;-tan(theta) 1])*[sr_MEAN(3)*h; -sr_MEAN(5)*h*sec(theta)];
plot(xypl(1),xypl(2),'ko','MarkerSize',8)
plot(xyisf(1),xyisf(2),'kv','MarkerSize',8,'MarkerFaceColor','k')
plot(xycy(1),xycy(2),'kd','MarkerSize',8,'MarkerFaceColor','k')
plot(xytiss(1),xytiss(2),'ks','Markersize',8,'MarkerFaceColor','k')
plot(xyrbc(1),xyrbc(2),'k*','Markersize',8)
plot(xymi(1),xymi(2),'kx','Markersize',8)
plot(xysr(1),xysr(2),'k+','Markersize',8)
legend('Plasma','ISF','Cytoplasm','Heart','RBC','Mitochondria','Sarcoplasmic Reticulum')

for i=1:11
    if(i==11)
        plot([x1(i) x2(i)],[y1(i) y2(i)],'k','LineWidth',0.75);
    else
        plot([x1(i) x2(i)],[y1(i) y2(i)],'k','LineWidth',0.75);
    end
    if(i==1)
        plot([x2(i) x3(12-i)],[y2(i) y3(12-i)],'k','LineWidth',0.75);
    else
        plot([x2(i) x3(12-i)],[y2(i) y3(12-i)],'k','LineWidth',0.75);
    end
    if(i==1)
        plot([x3(i) x1(i)],[y3(i) y1(i)],'k','LineWidth',0.75);
    else
        plot([x3(i) x1(i)],[y3(i) y1(i)],'k','LineWidth',0.75);
    end
end


%Saving the workspace with file name month_day_hour_minute.mat (with numerical vaues for month, day, hour, minute)
time = fix(clock);
save([num2str(time(2)) '_' num2str(time(3)) '_' num2str(time(4)) '_' num2str(time(5)) '.mat'])